# MoCV - Lists of Computer Vision algorithms.

### MoCV ("Mo" is "Open" in Vietnamese) is created to provide tutorials of Computer Vision algorithms.

List of Computer Vision algorithms:
1. Histogram - compute image histogram
2. Histogram Equalization - equalize image histogram to enhance image contrast
3. Linear Scale - lienarly scale image histogram
4. Segmentation by Optimal Thresholding
5. Will be updated soon

### Tutorials for testing
- Install MoCV: pip3 install MoCV
- Image Contrast Enhancement: python3 test.py 1
- Segmentation: python3 test.py 2
- Shifting images: python3 test.py 3 -100 70 
